/*
 * vifd/vif_notify.h
 * $Rev $
 *
 * Copyright (C) 2009 Reto Gantenbein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

/**
 * @file vif_notify.h
 * @brief Interface to the notification message handling on virtual interface
 * parameter changes.
 */

#ifndef __VIF_NOTIFY_H
#define __VIF_NOTIFY_H

/** Set debug output handler (default ignore) */
void
vif_notify_set_debug_function(int (*debug)(const char *format, ...));

/** Set error output handler (default stdout) */
void
vif_notify_set_error_function(int (*error)(const char *format, ...));

/**
 * Initialize notification message queue
 * @return Notification queue ID
 */
int
vif_notify_init();

/**
 * Delete notification message queue
 * @param msgq_id Message queue ID
 */
int
vif_notify_remove(int msgq_id);

/**
 * Send notification message for executed ioctl()
 * @param ioctl_type Ioctl() type (see wireless.h)
 * @param dev_name Virtual interface device name
 * @return 0 on success, -1 else
 */
int
vif_notify_ioctl(int ioctl_type, const char *dev_name);

/**
 * Poll the notification queue for arriving messages. On message reception run
 * the given msg_handler function with the message content
 * @param msg_handler Pointer to a client function handling parameter changes.
 * Its signature is void func(int ioctl_type, char *dev_name) */
void
vif_notify_poll(void *msg_handler);

#endif // __VIF_NOTIFY_H
