/*
 * vifd/vifd.h
 *
 * Copyright (C) 2008-2009 Reto Gantenbein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#ifndef __VIFD_H
#define __VIFD_H

/**
 * Defines data types for IPC communication via System V message queues and
 * shared memory
 */

/** INCLUDES ******************************************************************/
#include <sys/types.h>
#include <sys/ipc.h>
#include <sys/msg.h>
#include <sys/shm.h>
#include "iwlib.h"


/** IPC VALUES ****************************************************************/

/** define query error (compatible to iwconfig.c) */
#define IWERR_GET_EXT       -7

/** IPC shared memory/message queue key for communication with wireless tools */
#define IW_IPC_KEY          2009

/** IPC shared memory/message queue key for communication with PacketModeller */
#define PM_IPC_KEY          1337

/** Message types
 * -> don't use 0 for message type! (0 = first message in queue) */
#define IW_IOCTL            1   // ioctl request via iwreq
#define IW_ACK              2   // response to ioctl request
#define PM_UPDATE           3   // update request for packetmodeller
#define PM_ACK              4   // response to update request

/** Iwreq acknowledge */
#define IPC_OK              0x0000   // found valid iwreq data (default)
#define IPC_FAIL            0x0001   // error querying iwreq property/device
#define IWREQ_DATA          0x0010   // iwreq response contains shared memory data

/** Shared memory size
 * shared memory is used to store the iwparam->data content, standard ioctls
 * only use 32 bytes, however if SIOCGIWPRIV is used the size has to be
 * enlarged, because the return is depending on the number of supported private
 * ioctls */
#define NUM_IOCTL_PRIV      1   // needs to be adapted if you add more ioctls
                                // to libvif.h:vif_private_args[]
#define IW_SHARED_MEM_SIZE  NUM_IOCTL_PRIV * sizeof(struct iw_priv_args)


/** IPC DATATYPES *************************************************************/

/** Message structure */
struct iwreq_msg {
    long mtype;
    int iwreq_ack;
    int iwreq_property;         // property to set/query
    struct iwreq iw_request;
};

struct pm_msg {
    long mtype;
    int vif_index;
    int property;
};

/** Shared Memory format */
struct vif_info {
    char vif_name[IFNAMSIZ + 1];
    wireless_info vif_config;
};

/** Message sizes */
#define IW_MSG_SIZE         sizeof(struct iwreq_msg)
#define PM_MSG_SIZE         sizeof(struct pm_msg)

#endif
